@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 partially based on C++ code from:
  - Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
@@ -31,11 +31,11 @@ import random
 from collections import defaultdict
 import sqlite3
 
+from mi18n import i18n, i18ncE
 from kde import appdataDir
 from util import Duration
-from log import logInfo, logWarning, logException, logError, logDebug, m18ncE, m18n
-from common import IntDict, Options, Internal, Debug, nativeStringArgs, unicodeString
-from common import unicode, isPython3
+from log import logInfo, logWarning, logException, logError, logDebug, id4
+from common import IntDict, Options, Internal, Debug
 
 class QueryException(Exception):
 
@@ -79,7 +79,7 @@ class DBCursor(sqlite3.Cursor):
                     break
                 except sqlite3.OperationalError as exc:
                     logDebug(
-                        u'{} failed after {} tries:{}'.format(self, _, ' '.join(exc.args)))
+                        '{} failed after {} tries:{}'.format(self, _, ' '.join(exc.args)))
                     time.sleep(1)
                 else:
                     break
@@ -89,7 +89,7 @@ class DBCursor(sqlite3.Cursor):
             self.failure = None
         except sqlite3.Error as exc:
             self.failure = exc
-            msg = u'ERROR in %s: %s for %s' % (
+            msg = 'ERROR in %s: %s for %s' % (
                 self.connection.path,
                 exc.message if hasattr(exc, 'message') else '',
                 self)
@@ -105,8 +105,7 @@ class DBCursor(sqlite3.Cursor):
     def __str__(self):
         """the statement"""
         if self.parameters is not None:
-            native = nativeStringArgs(self.parameters)
-            return "{cmd} [{args}]".format(cmd=self.statement, args=native)
+            return "{cmd} [{args}]".format(cmd=self.statement, args=self.parameters)
         else:
             return self.statement
 
@@ -117,7 +116,7 @@ class DBHandle(sqlite3.Connection):
 
     # pylint: disable=no-member
 
-    def __init__(self, path):
+    def __init__(self, path: str):
         assert Internal.db is None, id(self)
         Internal.db = self
         self.inTransaction = None
@@ -126,28 +125,32 @@ class DBHandle(sqlite3.Connection):
         try:
             sqlite3.Connection.__init__(self, self.path, timeout=10.0)
         except sqlite3.Error as exc:
-            logException(
-                u'opening %s: %s' %
-                (unicodeString(self.path), exc.message))
+            if hasattr(exc, 'message'):
+                msg = exc.message
+            elif hasattr(exc, 'args'):
+                msg = ' '.join(exc.args)
+            else:
+                msg = ''
+            logException('opening %s: %s' % (self.path, msg))
         if self.hasTable('general'):
             cursor = self.cursor()
             cursor.execute('select ident from general')
             self.identifier = cursor.fetchone()[0]
         if Debug.sql:
-            logDebug(u'Opened %s with identifier %s' % (
-                unicodeString(self.path), self.identifier))
+            logDebug('Opened %s with identifier %s' % (
+                self.path, self.identifier))
 
     def __enter__(self):
         self.inTransaction = datetime.datetime.now()
         if Debug.sql:
-            logDebug(u'starting transaction')
+            logDebug('starting transaction')
         return sqlite3.Connection.__enter__(self)
 
     def __exit__(self, *args):
         self.inTransaction = None
         sqlite3.Connection.__exit__(self, *args)
         if Debug.sql:
-            logDebug(u'finished transaction')
+            logDebug('finished transaction')
 
     @staticmethod
     def dbPath():
@@ -158,11 +161,8 @@ class DBHandle(sqlite3.Connection):
         @rtype: C{str}
         """
         name = 'kajonggserver' if Internal.isServer else 'kajongg'
-        if isPython3:
-            name += '3.db'
-        else:
-            name += '.db'
-        return Options.dbPath if Options.dbPath else appdataDir() + name
+        name += '3.db'
+        return Options.dbPath if Options.dbPath else os.path.join(appdataDir(), name)
 
     @property
     def name(self):
@@ -171,7 +171,7 @@ class DBHandle(sqlite3.Connection):
         name = stack[-3]
         if name in ('__exit__', '__init__'):
             name = stack[-4]
-        return u'%s on %s (%x)' % (name, unicodeString(self.path), id(self))
+        return '%s on %s (%x)' % (name, self.path, id4(self))
 
     def commit(self, silent=None):
         """commit and log it"""
@@ -180,7 +180,7 @@ class DBHandle(sqlite3.Connection):
         except sqlite3.Error as exc:
             if not silent:
                 logWarning(
-                    u'%s cannot commit: %s :' %
+                    '%s cannot commit: %s :' %
                     (self.name, exc.message))
 
     def rollback(self, silent=None):
@@ -188,19 +188,17 @@ class DBHandle(sqlite3.Connection):
         try:
             sqlite3.Connection.rollback(self)
             if not silent and Debug.sql:
-                logDebug(u'%x rollbacked transaction' % id(self))
+                logDebug('%x rollbacked transaction' % id(self))
         except sqlite3.Error as exc:
-            logWarning(u'%s cannot rollback: %s' % (self.name, exc.message))
+            logWarning('%s cannot rollback: %s' % (self.name, exc.message))
 
     def close(self, silent=False):
         """just for logging"""
         if not silent and (Debug.sql or Debug.quit):
             if self is Internal.db:
-                logDebug(u'Closing Internal.db: %s' % unicodeString(self.path))
+                logDebug('Closing Internal.db: %s' % self.path)
             else:
-                logDebug(
-                    u'Closing DBHandle %s: %s' %
-                    (self, unicodeString(self.path)))
+                logDebug('Closing DBHandle %s: %s' % (self, self.path))
         if self is Internal.db:
             Internal.db = None
         try:
@@ -224,14 +222,14 @@ class DBHandle(sqlite3.Connection):
         return any(x[0] == field for x in cursor.description)
 
 
-class Query(object):
+class Query:
 
     """a wrapper arout python sqlite3, adding logging and some exception handling.
     For selecting queries we fill a list with ALL records which is never much.
     Every record is a list of all fields. q.records[0][1] is record 0, field 1.
     """
 
-    localServerName = m18ncE(
+    localServerName = i18ncE(
         'kajongg name for local game server',
         'Local Game')
 
@@ -267,7 +265,7 @@ class Query(object):
             self.failure = None
             self.records = list()
         if self.records and Debug.sql:
-            logDebug(u'result set:{}'.format(self.records))
+            logDebug('result set:{}'.format(self.records))
 
     def __str__(self):
         return '{} {}'.format(self.statement,
@@ -295,7 +293,7 @@ def initDb():
     return True
 
 
-class PrepareDB(object):
+class PrepareDB:
 
     """create or upgrade DB if needed"""
     schema = {}
@@ -393,8 +391,7 @@ class PrepareDB(object):
         @rtype: C{str}
         """
         if Internal.db.tableHasField('general', 'schemaversion'):
-            return str(Query('select schemaversion from general').records[0][0])
-            # Query returns unicode
+            return Query('select schemaversion from general').records[0][0]
         else:
             return '1.1.1'
 
@@ -402,10 +399,7 @@ class PrepareDB(object):
         """upgrade the structure of an existing kajongg database"""
         try:
             Internal.db = DBHandle(self.path)
-            if isPython3:
-                allVersions = list(['4.13.0', '8300'])
-            else:
-                allVersions = list(['4.13.0', '8200'])
+            allVersions = list(['4.13.0', '8300', '8301'])
             assert allVersions[-1] == str(Internal.defaultPort), '{} != {}'.format(
                 allVersions[-1], str(Internal.defaultPort))
             # skip versions before current db versions:
@@ -419,12 +413,10 @@ class PrepareDB(object):
                     if hasattr(self, updateMethodName):
                         getattr(self, updateMethodName)()
                     Query('UPDATE general SET schemaversion=?', (version,))
-                logInfo(m18n('Database %1 updated from schema %2 to %3',
+                logInfo(i18n('Database %1 updated from schema %2 to %3',
                              Internal.db.path, currentVersion, version), showDialog=True)
         except sqlite3.Error as exc:
-            logException(
-                u'opening %s: %s' %
-                (unicodeString(self.path), exc.message))
+            logException('opening %s: %s' % (self.path, exc.message))
         finally:
             Internal.db.close(silent=True)
 
@@ -522,37 +514,6 @@ class PrepareDB(object):
               'select id,seed,autoplay,starttime,endtime,ruleset,p0,p1,p2,p3 from gameback')
         Query('drop table gameback')
 
-    @staticmethod
-    def stopGamesWithRegex():
-        """we do not support Regex rules anymore.
-        Mark all games using them as finished - until somebody
-        complains. So for now always return False"""
-        if not Internal.db.hasTable('usedrule'):
-            return
-        usedRegexRulesets = Query("select distinct ruleset from usedrule "
-                                  "where definition not like 'F%' "
-                                  "and definition not like 'O%' "
-                                  "and definition not like 'int%' "
-                                  "and definition not like 'bool%' "
-                                  "and definition<>'' "
-                                  "and definition not like 'XEAST9X%'").records
-        usedRegexRulesets = list(unicode(x[0]) for x in usedRegexRulesets)
-        if not usedRegexRulesets:
-            return
-        openRegexGames = Query("select id from game "
-                               "where endtime is null "
-                               "and ruleset in (%s)" % ','.join(usedRegexRulesets)).records
-        openRegexGames = list(x[0] for x in openRegexGames)
-        if not openRegexGames:
-            return
-        logInfo(
-            'Marking games using rules with regular expressions as finished: %s' %
-            openRegexGames)
-        for openGame in openRegexGames:
-            endtime = datetime.datetime.now().replace(
-                microsecond=0).isoformat()
-            Query('update game set endtime=? where id=?', (endtime, openGame))
-
     def removeUsedRuleset(self):
         """eliminate usedruleset and usedrule"""
         if Internal.db.hasTable('usedruleset'):
@@ -618,7 +579,6 @@ class PrepareDB(object):
         if not Internal.db.tableHasField('score', 'notrotated'):
             Query('ALTER TABLE score add notrotated integer default 0')
         self.removeUsedRuleset()
-        self.stopGamesWithRegex()
 
     @staticmethod
     def __generateDbIdent():
@@ -630,5 +590,5 @@ class PrepareDB(object):
             Query("INSERT INTO general(ident) values(?)", (dbIdent,))
             if Debug.sql:
                 logDebug(
-                    u'generated new dbIdent %s for %s' %
+                    'generated new dbIdent %s for %s' %
                     (dbIdent, Internal.db.path))
